#!/bin/bash

echo
echo ================
echo Tektrans - Finnet AD2MT VPNC configurator
echo ================
echo

read -p 'VPNC username: ' vpncuser < /dev/tty
if [ -z "$vpncuser" ]; then
	echo "Invalid vpnc user";
	exit
fi

read -p 'VPNC password: ' vpncpass < /dev/tty
if [ -z "$vpncpass" ]; then
	echo "Invalid vpnc password";
	exit
fi

read -p 'IPSEC secret: ' ipsecsecret < /dev/tty
if [ -z "$ipsecsecret" ]; then
	echo "Invalid ipssec secret";
	exit
fi


set -x

sudo yum -y install vpnc
sed 2iINTERNAL_IP4_DNS= /etc/vpnc/vpnc-script | sudo tee /etc/vpnc/vpnc-script.patched
sudo mv /etc/vpnc/vpnc-script.patched /etc/vpnc/vpnc-script
sudo chmod +x /etc/vpnc/vpnc-script

sudo tee /etc/systemd/system/vpnc@.service << EOF
[Unit]
Description=VPNC Client %i
After=syslog.target network.target
StartLimitIntervalSec=0

[Service]
Type=simple
ExecStart=/usr/sbin/vpnc --no-detach --ifname tun-%i %i
Restart=always
User=root
Group=root
RestartSec=2

[Install]
WantedBy=multi-user.target
EOF

sudo tee /etc/vpnc/ad2mt.conf << EOF
IPSec gateway vpn.finnet.co.id
IPSec ID ad2mt
Domain WORKGROUP
Vendor cisco
NAT Traversal Mode natt
IKE DH Group dh2
Perfect Forward Secrecy server
Local Addr 0.0.0.0
Local Port 500
Cisco UDP Encapsulation Port 10000
DPD idle timeout (our side) 300
IKE Authmode psk
IPSEC target network 0.0.0.0/0.0.0.0
EOF

echo Xauth username $vpncuser | sudo tee -a /etc/vpnc/ad2mt.conf
echo Xauth password $vpncpass | sudo tee -a /etc/vpnc/ad2mt.conf
echo IPSec secret $ipsecsecret | sudo tee -a /etc/vpnc/ad2mt.conf

sudo systemctl daemon-reload
sudo systemctl enable vpnc@ad2mt
sudo systemctl restart vpnc@ad2mt

echo
cat /etc/vpnc/ad2mt.conf
